import click
import yaml_stripper


@click.command()
@click.argument("input_file", type=click.File("r"))
@click.argument("output_file", type=click.File("w"))
@click.option(
    "--fields", "-f", multiple=True, help="Fields to remove from the YAML file."
)
def main(input_file, output_file, fields):
    """
    Strip specified fields from a YAML file.

    INPUT_FILE: The YAML file to read.
    OUTPUT_FILE: The file to write the stripped YAML to.
    FIELDS: Fields to remove from the YAML file.
    """
    # Load the input YAML file
    yaml_data = yaml_stripper.load_yaml(input_file)

    # Remove specified fields from the YAML data
    stripped_yaml = yaml_stripper.strip_fields(yaml_data, fields)

    # Write the stripped YAML to the output file
    yaml_stripper.dump_yaml(stripped_yaml, output_file)


if __name__ == "__main__":
    main()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="yaml-stripper",
    version="0.1.7",
    author="Wagner Silva",
    author_email="wra.silva@gmail.com",
    description="A command-line tool for removing specified fields from YAML files.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/your_username/yaml-stripper",
    packages=setuptools.find_packages(),
    project_urls={
        "Bug Tracker": "https://github.com/vavasilva/YamlStripper",
        "Documentation": "https://github.com/vavasilva/YamlStripper",
        "Source Code": "https://github.com/vavasilva/YamlStripper",
        "Homepage": "https://github.com/vavasilva/YamlStripper"
    },
    entry_points={
        'console_scripts': ['yaml-stripper=YamlStripper.yaml_stripper:main'],
    },
    install_requires=[
        'PyYAML>=5.3.1',
        'click>=8.0.0',
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
